@@ -3,7 +3,7 @@ import base64
 import requests
 from google.cloud import pubsub_v1
 from expressmoney.core import Core
-from expressmoney.dataclasses import Status
+from expressmoney.dataclasses import Result
 from google.cloud import tasks_v2
 import datetime
 
@@ -134,7 +134,7 @@ class Functions:
         profile_obj = profile.retrieve(self.initial_event.get('user'))
         data = {**user_obj, **profile_obj}
 
-        return Status(Status.SUCCESS, 'Demo result comment in _service_new()')
+        return Result(Status.SUCCESS, 'Demo result comment in _service_new()')
 
     def _in_process(self):
         """Подготовка доменных данных и передача их в сервиса _service_in_process()"""
